@@ -4,7 +4,9 @@
 
 #include "gconf.h"
 
-#define GST_GCONF_DIR "/system/gstreamer"
+#ifndef GST_GCONF_DIR
+#error "GST_GCONF_DIR is not defined !"
+#endif
 
 static GConfClient *_gst_gconf_client = NULL; /* GConf connection */
 
@@ -57,32 +59,64 @@ gst_bin_find_unconnected_pad (GstBin *bin, GstPadDirection direction)
 
 /* external functions */
 
+/**
+ * gst_gconf_get_string:
+ * @key: a #gchar corresponding to the key you want to get.
+ *
+ * Get GConf key @key's string value.
+ *
+ * Returns: a #gchar string containing @key's value.
+ */
 gchar *
 gst_gconf_get_string (const gchar *key)
 {
   GError *error = NULL;
   gchar *value = NULL;
-  gchar *full_key = g_strdup_printf ("%s/%s", GST_GCONF_DIR, key); 
+  gchar *full_key = g_strdup_printf ("%s/%s", GST_GCONF_DIR, key);
 
 
   value = gconf_client_get_string (gst_gconf_get_client (), full_key, &error);
   g_free (full_key);
 
-  if (value) 
-    return value;
-  else
-    return NULL;
-  // this is a good idea: return g_strdup (default_val);
+  if (error)
+  {
+    g_warning ("gst_gconf_get_string: error: %s\n", error->message);
+    g_error_free (error);
+  }
+  /* FIXME: decide if we want to strdup this value; if we do, check for NULL */
+  return value;
 }
 
+/**
+ * gst_gconf_set_string:
+ * @key: a #gchar corresponding to the key you want to set.
+ * @value: a #gchar containing key value.
+ *
+ * Set GConf key @key to string value @value.
+ */
 void
 gst_gconf_set_string (const gchar *key, const gchar *value)
 {
-  gconf_client_set_string (gst_gconf_get_client (), key, value, NULL);
+  GError *error = NULL;
+  gchar *full_key = g_strdup_printf ("%s/%s", GST_GCONF_DIR, key);
+
+  gconf_client_set_string (gst_gconf_get_client (), full_key, value, &error);
+  if (error)
+  {
+    g_warning ("gst_gconf_set_string: error: %s\n", error->message);
+    g_error_free (error);
+  }
+  g_free (full_key);
 }
 
-/* this function renders the given description to a bin,
- * and ghosts at most one unconnected src pad and one unconnected sink pad */
+/**
+ * gst_gconf_render_bin_from_description:
+ * @description: a #gchar string describing the bin.
+ *
+ * Render bin from description @description.
+ *
+ * Returns: a #GstElement containing the rendered bin.
+ */
 GstElement *
 gst_gconf_render_bin_from_description (const gchar *description)
 {
@@ -113,8 +147,14 @@ gst_gconf_render_bin_from_description (const gchar *description)
   return bin;
 }
 
-/* this function reads the gconf key, parses the pipeline bit to a bin,
- * and ghosts at most one unconnected src pad and one unconnected sink pad */
+/**
+ * gst_gconf_render_bin_from_key:
+ * @key: a #gchar string corresponding to a GConf key.
+ *
+ * Render bin from GConf key @key.
+ *
+ * Returns: a #GstElement containing the rendered bin.
+ */
 GstElement *
 gst_gconf_render_bin_from_key (const gchar *key)
 {
@@ -127,12 +167,15 @@ gst_gconf_render_bin_from_key (const gchar *key)
   return bin;
 }
 
-/*
-guint		gst_gconf_notify_add		(const gchar *key,
-    						 GConfClientNotifyFunc func,
-						 gpointer user_data);
-*/
-
+/**
+ * gst_gconf_get_default_audio_sink:
+ *
+ * Render audio output bin from GStreamer GConf key : "default/audiosink".
+ * If key is invalid osssink is used as default output plugin.
+ *
+ * Returns: a #GstElement containing the audio output bin, or NULL if
+ * everything failed.
+ */
 GstElement *
 gst_gconf_get_default_audio_sink (void)
 {
@@ -150,6 +193,15 @@ gst_gconf_get_default_audio_sink (void)
   return ret;
 }
 
+/**
+ * gst_gconf_get_default_video_sink:
+ *
+ * Render video output bin from GStreamer GConf key : "default/videosink".
+ * If key is invalid xvideosink is used as default output plugin.
+ *
+ * Returns: a #GstElement containing the video output bin, or NULL if
+ * everything failed.
+ */
 GstElement *
 gst_gconf_get_default_video_sink (void)
 {
@@ -167,6 +219,15 @@ gst_gconf_get_default_video_sink (void)
   return ret;
 }
 
+/**
+ * gst_gconf_get_default_audio_src:
+ *
+ * Render audio acquisition bin from GStreamer GConf key : "default/audiosrc".
+ * If key is invalid osssrc is used as default source.
+ *
+ * Returns: a #GstElement containing the audio source bin, or NULL if
+ * everything failed.
+ */
 GstElement *
 gst_gconf_get_default_audio_src (void)
 {
@@ -184,6 +245,16 @@ gst_gconf_get_default_audio_src (void)
   return ret;
 }
 
+/**
+ * gst_gconf_get_default_video_src:
+ *
+ * Render video acquisition bin from GStreamer GConf key :
+ * "default/videosrc". If key is invalid videotestsrc
+ * is used as default source.
+ *
+ * Returns: a #GstElement containing the video source bin, or NULL if
+ * everything failed.
+ */
 GstElement *
 gst_gconf_get_default_video_src (void)
 {
@@ -201,6 +272,32 @@ gst_gconf_get_default_video_src (void)
   return ret;
 }
 
+/**
+ * gst_gconf_get_default_visualisation_element:
+ *
+ * Render visualisation bin from GStreamer GConf key : "default/visualisation".
+ * If key is invalid goom is used as default visualisation element.
+ *
+ * Returns: a #GstElement containing the visualisation bin, or NULL if
+ * everything failed.
+ */
+GstElement *
+gst_gconf_get_default_visualisation_element (void)
+{
+  GstElement *ret = gst_gconf_render_bin_from_key ("default/visualisation");
+  
+  if (!ret) {
+    ret = gst_element_factory_make ("goom", NULL);
+  
+    if (!ret)
+      g_warning ("No GConf default visualisation plugin key and goom doesn't work");
+    else
+      g_warning ("GConf visualisation plugin not found, using goom");
+  }
+
+  return ret;
+}
+
 static gboolean
 plugin_init (GModule *module, GstPlugin *plugin)
 {
